nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

MiscCtrlDpRegDisableStrictMode

Enum MiscCtrlDpRegDisableStrictMode 

#[repr(u8)]
pub enum MiscCtrlDpRegDisableStrictMode { _RESERVED_0 = 0, AHBTM = 1, AHBSM1 = 2, _RESERVED_3 = 3, }

Variants



_RESERVED_0 = 0



AHBTM = 1

Master can access memories and peripherals at the same level or below that level.



AHBSM1 = 2

Master can access memories and peripherals at same level only



_RESERVED_3 = 3

Implementations