#[repr(u8)]pub enum MiscCtrlDpRegEnableSecureChecking {
_RESERVED_0 = 0,
ENABLED = 1,
DISABLED = 2,
_RESERVED_3 = 3,
}Variants
_RESERVED_0 = 0
ENABLED = 1
Enables secure checking. Violation can be detected when the security level of a transaction does not meet the security rule of the slave or memory to be accessed.
DISABLED = 2
Disables secure checking. Even if the security level of a transaction does not conform to the security rule of the slave or memory, it will not be detected as a violation.
_RESERVED_3 = 3
Implementations